//===-- SystemInitializer.cpp -----------------------------------*- C++ -*-===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

#include "lldb/Initialization/SystemInitializer.h"

using namespace lldb_private;

SystemInitializer::SystemInitializer() {}

SystemInitializer::~SystemInitializer() {}
